@@ -212,6 +212,7 @@ class IPyNbFile(pytest.File):
             'output_type',
             'name',
             'execution_count',
+            'application/vnd.jupyter.widget-view+json'  # Model IDs are random
         )
         if not config.option.nbdime:
             self.skip_compare = self.skip_compare + ('image/png', 'image/jpeg')
@@ -288,18 +289,23 @@ class IPyNbFile(pytest.File):
                 with warnings.catch_warnings(record=True) as ws:
                     options = defaultdict(bool, find_metadata_tags(cell.metadata))
                     comment_opts = dict(find_comment_markers(cell.source))
-                    if set(comment_opts.keys()) & set(options.keys()):
-                        warnings.warn(
-                            "Overlapping options from comments and metadata, "
-                            "using options from comments: %s" %
-                            str(set(comment_opts.keys()) & set(options.keys())))
-                    for w in ws:
-                        self.parent.config.warn(
-                            "C1",
-                            str(w.message),
-                            '%s:Cell %d' % (
-                                getattr(self, "fspath", None),
-                                cell_num))
+                loc = '%s:Cell %d' % (getattr(self, "fspath", None), cell_num)
+                if set(comment_opts.keys()) & set(options.keys()):
+                    warnings.warn_explicit(
+                        "Overlapping options from comments and metadata, "
+                        "using options from comments: %s" %
+                        str(set(comment_opts.keys()) & set(options.keys())),
+                        category=UserWarning,
+                        filename=loc,
+                        lineno=0
+                    )
+                for w in ws:
+                    warnings.warn_explicit(
+                        str(w.message),
+                        category=UserWarning,
+                        filename=loc,
+                        lineno=0
+                    )
                 options.update(comment_opts)
                 options.setdefault('check', self.compare_outputs)
                 yield IPyNbCell('Cell ' + str(cell_num), self, cell_num,
@@ -789,7 +795,7 @@ class IPyNbCell(pytest.Item):
         return s
 
 
-carriagereturn_pat = re.compile(r'.*\r(?=[^\n])')
+carriagereturn_pat = re.compile(r'^.*\r(?=[^\n])', re.MULTILINE)
 backspace_pat = re.compile(r'[^\n]\b')
 
 
